#!/usr/bin/env python3


def check_winner(board):
    for idx, c in enumerate("XO"):
        for i in range(3):
            if all(board[3 * i + j] == c for j in range(3)):
                return idx

        for i in range(3):
            if all(board[i + 3 * j] == c for j in range(3)):
                return idx

        if board[0] == board[4] == board[8] == c:
            return idx

        if board[2] == board[4] == board[6] == c:
            return idx

    return None


def play(board):
    player = "X" if board.count("X") == board.count("O") else "O"
    for i, c in enumerate(board):
        if c == ".":
            yield board[:i] + player + board[i + 1 :]


def precompute():
    ways = {}

    def solve(board):
        winner = check_winner(board)

        if winner is None:
            ways[board] = (0, 0)
            for new_board in play(board):
                sub = solve(new_board)
                ways[board] = tuple(x + y for x, y in zip(ways[board], sub))
        elif winner == 0:
            ways[board] = (1, 0)
        elif winner == 1:
            ways[board] = (0, 1)
        else:
            assert False

        return ways[board]

    solve(".........")
    return ways


def main():
    ans = precompute()
    t = int(input())
    for _ in range(t):
        board = input()
        if board not in ans:
            print(-1, -1)
        else:
            print(*ans[board])


if __name__ == "__main__":
    main()
